@@ -13,7 +13,7 @@ class MarkClient:
   def __init__(self):
     self.server_url = None
     self.verbose = False
-    self.proxy = {'http': '', 'https': ''}
+    self.proxy = None
 
   def get_server_status(self):
     print "- Get the status of the server"
@@ -56,6 +56,19 @@ class MarkClient:
     sorted_result_data = sorted(result_data, key=itemgetter('score'), reverse=True)
     return sorted_result_data
 
+  def get_unique_subject_count(self, subject):
+    print "- Fetching count of unique subjects in Evidences"
+    parameters = {'method': 'findUniqueSubjects',
+                  'params': json.dumps([subject]),
+                  'id': 123}
+    response = requests.get(self.server_url, params=parameters, proxies=self.proxy)
+    if self.verbose:
+      print "-- Status of the get_unique_subject_count request:"
+      print "-- " + str(response.headers)
+    result_data = response.json()["result"]
+    return result_data
+
+
   def set_server_url(self, url):
     self.server_url = url
 
